@@ -31,6 +31,7 @@ from azure.datalake.store import core, lib, multithread
 
 from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import _ensure_prefixes, get_field
 
 
 class AzureDataLakeHook(BaseHook):
@@ -44,10 +45,10 @@ class AzureDataLakeHook(BaseHook):
     :param azure_data_lake_conn_id: Reference to the :ref:`Azure Data Lake connection<howto/connection:adl>`.
     """
 
-    conn_name_attr = 'azure_data_lake_conn_id'
-    default_conn_name = 'azure_data_lake_default'
-    conn_type = 'azure_data_lake'
-    hook_name = 'Azure Data Lake'
+    conn_name_attr = "azure_data_lake_conn_id"
+    default_conn_name = "azure_data_lake_default"
+    conn_type = "azure_data_lake"
+    hook_name = "Azure Data Lake"
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
@@ -57,28 +58,27 @@ class AzureDataLakeHook(BaseHook):
         from wtforms import StringField
 
         return {
-            "extra__azure_data_lake__tenant": StringField(
-                lazy_gettext('Azure Tenant ID'), widget=BS3TextFieldWidget()
-            ),
-            "extra__azure_data_lake__account_name": StringField(
-                lazy_gettext('Azure DataLake Store Name'), widget=BS3TextFieldWidget()
+            "tenant": StringField(lazy_gettext("Azure Tenant ID"), widget=BS3TextFieldWidget()),
+            "account_name": StringField(
+                lazy_gettext("Azure DataLake Store Name"), widget=BS3TextFieldWidget()
             ),
         }
 
     @staticmethod
+    @_ensure_prefixes(conn_type="azure_data_lake")
     def get_ui_field_behaviour() -> dict[str, Any]:
         """Returns custom field behaviour"""
         return {
-            "hidden_fields": ['schema', 'port', 'host', 'extra'],
+            "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
-                'login': 'Azure Client ID',
-                'password': 'Azure Client Secret',
+                "login": "Azure Client ID",
+                "password": "Azure Client Secret",
             },
             "placeholders": {
-                'login': 'client id',
-                'password': 'secret',
-                'extra__azure_data_lake__tenant': 'tenant id',
-                'extra__azure_data_lake__account_name': 'datalake store',
+                "login": "client id",
+                "password": "secret",
+                "tenant": "tenant id",
+                "account_name": "datalake store",
             },
         }
 
@@ -88,16 +88,21 @@ class AzureDataLakeHook(BaseHook):
         self._conn: core.AzureDLFileSystem | None = None
         self.account_name: str | None = None
 
+    def _get_field(self, extras, name):
+        return get_field(
+            conn_id=self.conn_id,
+            conn_type=self.conn_type,
+            extras=extras,
+            field_name=name,
+        )
+
     def get_conn(self) -> core.AzureDLFileSystem:
         """Return a AzureDLFileSystem object."""
         if not self._conn:
             conn = self.get_connection(self.conn_id)
-            service_options = conn.extra_dejson
-            self.account_name = service_options.get('account_name') or service_options.get(
-                'extra__azure_data_lake__account_name'
-            )
-            tenant = service_options.get('tenant') or service_options.get('extra__azure_data_lake__tenant')
-
+            extras = conn.extra_dejson
+            self.account_name = self._get_field(extras, "account_name")
+            tenant = self._get_field(extras, "tenant")
             adl_creds = lib.auth(tenant_id=tenant, client_secret=conn.password, client_id=conn.login)
             self._conn = core.AzureDLFileSystem(adl_creds, store_name=self.account_name)
             self._conn.connect()
@@ -109,7 +114,6 @@ class AzureDataLakeHook(BaseHook):
 
         :param file_path: Path and name of the file.
         :return: True if the file exists, False otherwise.
-        :rtype: bool
         """
         try:
             files = self.get_conn().glob(file_path, details=False, invalidate_cache=True)
